@@ -9,7 +9,7 @@
     @license: GNU GPL, see COPYING for details.
 """
 
-__version__ = "0.2.2"
+__version__ = "0.2.3"
 
 # Change this to the directory that the Graphviz binaries (dot, neato, etc.)
 # are installed in.
@@ -303,7 +303,7 @@ class Parser:
 
         "Return a (width, height) tuple using the 'attrs' dictionary."
 
-        if attrs and attrs.has_key("width") and attrs.has_key("height"):
+        if attrs and attrs.get("width") and attrs.get("height"):
             return attrs["width"], attrs["height"]
         else:
             return None
